@@ -37,7 +37,7 @@ def passepartout_login_view(request, token):
             raise Http404("No next url")
 
         try:
-            passepartout = Passepartout.objects.get(deleted=False, token=token)
+            passepartout = Passepartout.objects.get(is_active=True, token=token)
 
         except Passepartout.DoesNotExist:
             logger.warning("Passepartout token not found, redirecting to login")
@@ -93,7 +93,7 @@ def passepartout_login_view(request, token):
 
         if is_last_bump:
             logger.info('Is last login bump')
-            passepartout.deleted = True
+            passepartout.is_active = False
             passepartout.save()
             goes_to = nextUrl
         else:
