@@ -102,7 +102,7 @@ class ProfileForm(forms.Form):
         picture_file = self.cleaned_data['picture']
         picture_file_type = type(picture_file)
 
-        if picture_file_type not in [str, None] and picture_file_type in [InMemoryUploadedFile, TemporaryUploadedFile]:
+        if picture_file_type not in (str, None) and picture_file_type in (InMemoryUploadedFile, TemporaryUploadedFile):
             picture_bin = picture_file.file.read()
             picture_image = Image.open(BytesIO(picture_bin))
             picture_format = picture_image.format
